/*
** brl.h for trf in /home/obert01/work/trf/src
**
** Made by Olivier BERT
** Login   <obert01@epita.fr>
**
** Started on  Wed Mar 16 18:41:29 2005 Olivier BERT
** Last update Sun Mar 26 21:22:59 2006 Olivier BERT
*/

#ifndef __BRL_H_
# define __BRL_H_


#include <iconv.h>
#include <stdio.h>
#include <string.h>
#include <brltty/api.h>

/* TRF version number */
# define TRF_VERSION	"TRF 0.2.4"

/* Exit codes */
# define E_OK		0
# define E_BRLAPI_ERROR	3
# define E_READ		4
# define E_WRITE	5

/* some defines */
# define HEADER_LINE "\x0cK/CP8 5.08-0C 1 16 FU \x1bi\x1b$"
# define RULE_LINE "\x0bR 25,80,T8,16,24,32,40,48,56,64,72\x1BP\x1B$"
# define READ_LINE	"\002FR"
# define CLOSE_FILE	"\002FC"

# define BUFFER_SIZE		500
# define MAXENT		5

/*
** A structure that contains all informations about the file transfert */
typedef struct
{
  /* the braille terminal selected file */
  unsigned short brfilenum;
  unsigned short pcfilenum;
  /* the file extension index we are searching for on the braille terminal
  ** It is a number between 0 and 3. 0 = 'K' 1 = 'L' etc... */
  unsigned char		curextnum;
  /* L'extension du fichier : K, L, B, T, A. Ce champ est utilis
     que pour le transfert pc->br. Concrtement, on pourrait se passer
     de cette variable ou de celle du dessus */
  unsigned char	curext;
  /* cette variable dit si on est en train de changer le type de transfert (br->pc ou pc->br,
     si on change l'extension ou si on change le nom du fichier. */
  unsigned char		status;
  /* Cette variable dit si on est en train de transfrer du terminal vers le pc ou pas */
  unsigned char		brpc;
  /* Le nombre de fichiers sur le rpertoire PC courant */
  int		n;
  /* Liste des fichiers PC dans le rpertoire courant */
  struct dirent**		list;
  /* Pour le transfert pc->br, un descripteur de fichier pointant sur le fichier  transfrer */
  int		fd;
  /* Stream associated with fd */
  FILE*		fs;
  /* nom du fichier  transfrer */
  char	filename[9];
  /* convertisseurs pour les caractres */
  iconv_t	dos2unix;
  iconv_t	unix2dos;
} t_env;


int		brl_init(void);
int		brl_close(void);
int             brl_message(char *str, unsigned char cursorpos);
int		brl_listfiles(t_env*);


void		trf_abort(int exitstatus);
ssize_t		brl_read(unsigned char *);
ssize_t		brl_write(unsigned char *, size_t len);
void	brl_writeStr(char *str);

#endif
